import { motion } from "framer-motion";
import { useState } from "react";
import { CourseDto } from "@nicestack/common";
import { EmptyStateIllustration } from "@web/src/components/presentation/EmptyStateIllustration";
import { useNavigate } from "react-router-dom";

interface CourseCardProps {
    course: CourseDto;
    type: "created" | "enrolled";
}

const CourseCard = ({ course, type }: CourseCardProps) => {
    return (
        <motion.div
            initial={{ opacity: 0, y: 20 }}
            animate={{ opacity: 1, y: 0 }}
            whileHover={{ scale: 1.02 }}
            className="group relative overflow-hidden rounded-2xl bg-white p-6 shadow-sm transition-all hover:shadow-md"
        >
            {/* Course Thumbnail */}
            <div className="relative mb-4 aspect-video w-full overflow-hidden rounded-xl">
                <motion.img
                    src={course.thumbnail || "/default-course-thumb.jpg"}
                    alt={course.title}
                    className="h-full w-full object-cover transition-transform duration-300 group-hover:scale-105"
                />
                <div className="absolute inset-0 bg-gradient-to-t from-black/40 to-transparent" />
                <div className="absolute bottom-2 left-2">
                    <span className="rounded-full bg-white/30 px-3 py-1 text-sm text-white backdrop-blur-sm">
                        {course.level}
                    </span>
                </div>
            </div>

            {/* Course Info */}
            <div className="space-y-2">
                <h3 className="text-xl font-medium text-gray-700">
                    {course.title}
                </h3>
                {course.subTitle && (
                    <p className="text-sm text-gray-500">
                        {course.subTitle}
                    </p>
                )}
            </div>

            {/* Course Stats */}
            <div className="mt-4 flex items-center justify-between text-sm">
                <div className="flex items-center space-x-2 text-gray-500">
                    <span>{course.totalLectures} lectures</span>
                    <span>•</span>
                    <span>{course.totalDuration} mins</span>
                </div>
                <div className="flex items-center space-x-1">
                    <span className="text-amber-400">★</span>
                    <span className="text-gray-600">
                        {course.averageRating.toFixed(1)}
                    </span>
                </div>
            </div>

            {/* Progress Bar (Only for enrolled courses) */}
            {type === "enrolled" && course.enrollments[0] && (
                <div className="mt-4">
                    <div className="relative h-2 w-full overflow-hidden rounded-full bg-gray-100">
                        <motion.div
                            initial={{ width: 0 }}
                            animate={{ width: `${course.enrollments[0].completionRate}%` }}
                            className="absolute left-0 top-0 h-full rounded-full bg-indigo-400"
                            transition={{ duration: 1, ease: "easeOut" }}
                        />
                    </div>
                    <p className="mt-1 text-right text-xs text-gray-400">
                        {course.enrollments[0].completionRate}% Complete
                    </p>
                </div>
            )}
        </motion.div>
    );
};
export default function CoursesPage() {
    const [activeTab, setActiveTab] = useState<"enrolled" | "created">("enrolled");
    const [courses, setCourses] = useState<CourseDto[]>([]);
    const navigate = useNavigate()
    const container = {
        hidden: { opacity: 0 },
        show: {
            opacity: 1,
            transition: {
                staggerChildren: 0.05,
                duration: 0.3
            },
        },
    };

    return (
        <div className="min-h-screen bg-slate-50 px-4 py-8 sm:px-6 lg:px-8">
            <div className="mx-auto max-w-7xl">
                {/* Header */}
                <div className="mb-8 flex items-center justify-between">
                    <div>
                        <h1 className="text-3xl font-semibold text-slate-800">
                            我的课程
                        </h1>
                        <div className="mt-4">
                            <nav className="flex space-x-4">
                                {["enrolled", "created"].map((tab) => (
                                    <motion.button
                                        key={tab}
                                        onClick={() => setActiveTab(tab as "enrolled" | "created")}
                                        className={`relative rounded-lg px-6 py-2.5 text-sm font-medium ${activeTab === tab
                                            ? "bg-blue-500 text-white shadow-sm shadow-sky-100"
                                            : "bg-white text-slate-600 hover:bg-white hover:text-blue-500 hover:shadow-sm"
                                            }`}
                                        whileHover={{ y: -2 }}
                                        whileTap={{ y: 0 }}
                                        transition={{ duration: 0.2 }}
                                    >
                                        {tab.charAt(0).toUpperCase() + tab.slice(1)} Courses
                                    </motion.button>
                                ))}
                            </nav>
                        </div>
                    </div>
                    {activeTab === "created" && (
                        <motion.button
                            initial={{ opacity: 0, x: 20 }}
                            animate={{ opacity: 1, x: 0 }}
                            whileHover={{ y: -2 }}
                            whileTap={{ y: 0 }}
                            onClick={() => {
                                navigate("/course/manage")
                            }}
                            transition={{ duration: 0.2 }}
                            className="flex items-center gap-2 rounded-lg bg-blue-500 px-6 py-3 text-sm font-medium text-white shadow-sm transition-all duration-200 hover:bg-blue-600 hover:shadow-md"
                        >
                            <span className="relative h-5 w-5">
                                <motion.svg
                                    xmlns="http://www.w3.org/2000/svg"
                                    fill="none"
                                    viewBox="0 0 24 24"
                                    strokeWidth={2}
                                    stroke="currentColor"
                                    className="h-5 w-5"
                                    whileHover={{ rotate: 90 }}
                                    transition={{ duration: 0.2 }}
                                >
                                    <path
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                        d="M12 4.5v15m7.5-7.5h-15"
                                    />
                                </motion.svg>
                            </span>
                            创建课程
                        </motion.button>
                    )}
                </div>

                {/* Course Grid */}
                <motion.div
                    variants={container}
                    initial="hidden"
                    animate="show"
                    className="grid gap-6 sm:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4"
                >
                    {courses.map((course) => (
                        <CourseCard
                            key={course.id}
                            course={course}
                            type={activeTab}
                        />
                    ))}
                </motion.div>

                {/* Empty State */}
                {courses.length === 0 && (
                    <motion.div
                        initial={{ opacity: 0 }}
                        animate={{ opacity: 1 }}
                        transition={{ duration: 0.3 }}
                        className="flex flex-col items-center justify-center rounded-xl bg-white p-8 text-center shadow-sm"
                    >
                        <EmptyStateIllustration />
                        <h3 className="mb-2 text-xl font-medium text-slate-800">
                            No courses found
                        </h3>
                        <p className="text-slate-500">
                            {activeTab === "enrolled"
                                ? "You haven't enrolled in any courses yet."
                                : "You haven't created any courses yet."}
                        </p>
                    </motion.div>
                )}
            </div>
        </div>
    );
}