import { createContext, useContext, ReactNode } from 'react';
import { useForm, FormProvider, SubmitHandler } from 'react-hook-form';
import { zodResolver } from '@hookform/resolvers/zod';
import { z } from 'zod';
import { CourseLevel, CourseStatus } from '@nicestack/common';
import { useCourse } from '@nicestack/client';

// 定义课程表单验证 Schema
const courseSchema = z.object({
    title: z.string().min(1, '课程标题不能为空'),
    subTitle: z.string().optional(),
    description: z.string().optional(),
    thumbnail: z.string().url().optional(),
    level: z.nativeEnum(CourseLevel),
    requirements: z.array(z.string()).optional(),
    objectives: z.array(z.string()).optional(),
    skills: z.array(z.string()).optional(),
    audiences: z.array(z.string()).optional(),
    status: z.nativeEnum(CourseStatus),
});
export type CourseFormData = z.infer<typeof courseSchema>;
interface CourseEditorContextType {
    onSubmit: SubmitHandler<CourseFormData>;
}
const CourseEditorContext = createContext<CourseEditorContextType | null>(null);
export function CourseFormProvider({ children }: { children: ReactNode }) {
    const { create } = useCourse()
    const methods = useForm<CourseFormData>({
        resolver: zodResolver(courseSchema),
        defaultValues: {
            status: CourseStatus.DRAFT,
            level: CourseLevel.BEGINNER,

            requirements: [],
            objectives: [],
            skills: [],
            audiences: [],
        },
    });

    const onSubmit: SubmitHandler<CourseFormData> = async (data: CourseFormData) => {
        try {
            // TODO: 实现API调用
            console.log('Form data:', data);
            await create.mutateAsync({
                data: {
                    ...data
                }
            })

        } catch (error) {
            console.error('Error submitting form:', error);
        }
    };

    return (
        <CourseEditorContext.Provider value={{ onSubmit }}>
            <FormProvider {...methods}>
                {children}
            </FormProvider>
        </CourseEditorContext.Provider>
    );
}

export const useCourseForm = () => {
    const context = useContext(CourseEditorContext);
    if (!context) {
        throw new Error('useCourseForm must be used within CourseFormProvider');
    }
    return context;
};